@@ -1,3 +1,6 @@
+// FIXME(thaJeztah): remove once we are a module; the go:build directive prevents go from downgrading language version to go1.16:
+//go:build go1.22
+
 package formatter
 
 import (
@@ -5,8 +8,7 @@ import (
 	"testing"
 )
 
-type dummy struct {
-}
+type dummy struct{}
 
 func (d *dummy) Func1() string {
 	return "Func1"
@@ -34,7 +36,7 @@ func (d *dummy) FullHeader() string {
 	return "FullHeader(should not be marshalled)"
 }
 
-var dummyExpected = map[string]interface{}{
+var dummyExpected = map[string]any{
 	"Func1": "Func1",
 	"Func4": 4,
 	"Func5": dummyType("Func5"),
