@@ -30,41 +30,54 @@ func TestTrustSignerRemoveErrors(t *testing.T) {
 		},
 	}
 	for _, tc := range testCases {
-		cmd := newSignerRemoveCommand(
-			test.NewFakeCli(&fakeClient{}))
-		cmd.SetArgs(tc.args)
-		cmd.SetOut(io.Discard)
-		assert.ErrorContains(t, cmd.Execute(), tc.expectedError)
+		tc := tc
+		t.Run(tc.name, func(t *testing.T) {
+			cmd := newSignerRemoveCommand(
+				test.NewFakeCli(&fakeClient{}))
+			cmd.SetArgs(tc.args)
+			cmd.SetOut(io.Discard)
+			cmd.SetErr(io.Discard)
+			assert.ErrorContains(t, cmd.Execute(), tc.expectedError)
+		})
 	}
 	testCasesWithOutput := []struct {
-		name          string
-		args          []string
-		expectedError string
+		name           string
+		args           []string
+		expectedError  string
+		expectedErrOut string
 	}{
 		{
-			name:          "not-an-image",
-			args:          []string{"user", "notanimage"},
-			expectedError: "error retrieving signers for notanimage",
+			name:           "not-an-image",
+			args:           []string{"user", "notanimage"},
+			expectedError:  "error removing signer from: notanimage",
+			expectedErrOut: "error retrieving signers for notanimage",
 		},
 		{
-			name:          "sha-reference",
-			args:          []string{"user", "870d292919d01a0af7e7f056271dc78792c05f55f49b9b9012b6d89725bd9abd"},
-			expectedError: "invalid repository name",
+			name:           "sha-reference",
+			args:           []string{"user", "870d292919d01a0af7e7f056271dc78792c05f55f49b9b9012b6d89725bd9abd"},
+			expectedError:  "error removing signer from: 870d292919d01a0af7e7f056271dc78792c05f55f49b9b9012b6d89725bd9abd",
+			expectedErrOut: "invalid repository name",
 		},
 		{
-			name:          "invalid-img-reference",
-			args:          []string{"user", "ALPINE"},
-			expectedError: "invalid reference format",
+			name:           "invalid-img-reference",
+			args:           []string{"user", "ALPINE"},
+			expectedError:  "error removing signer from: ALPINE",
+			expectedErrOut: "invalid reference format",
 		},
 	}
 	for _, tc := range testCasesWithOutput {
-		cli := test.NewFakeCli(&fakeClient{})
-		cli.SetNotaryClient(notaryfake.GetOfflineNotaryRepository)
-		cmd := newSignerRemoveCommand(cli)
-		cmd.SetArgs(tc.args)
-		cmd.SetOut(io.Discard)
-		cmd.Execute()
-		assert.Check(t, is.Contains(cli.ErrBuffer().String(), tc.expectedError))
+		tc := tc
+		t.Run(tc.name, func(t *testing.T) {
+			cli := test.NewFakeCli(&fakeClient{})
+			cli.SetNotaryClient(notaryfake.GetOfflineNotaryRepository)
+			cmd := newSignerRemoveCommand(cli)
+			cmd.SetArgs(tc.args)
+			cmd.SetOut(io.Discard)
+			cmd.SetErr(io.Discard)
+			err := cmd.Execute()
+			assert.Check(t, is.Error(err, tc.expectedError))
+			assert.Check(t, is.Contains(cli.ErrBuffer().String(), tc.expectedErrOut))
+		})
 	}
 }
 
